@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/python2.3
 # maybe you need to change the above line
 
 
@@ -362,7 +362,7 @@ class BasicSession:
             return
         self.reply('257 "%s" Directory created' % path)
 
-    def cmd_rmd(self, pat):
+    def cmd_rmd(self, path):
         path = self.joinpath(self.cwd, path)
         perm = self.logged and permcheck(path, self.user, self.group, self, "rmd")
         if not perm:
